@@ -31,7 +31,7 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-"Add/remove NFS mount points from LDAP to/from /etc/fstab and mount them"
+"""Add/remove NFS mount points from LDAP to/from /etc/fstab and mount them"""
 
 from __future__ import print_function
 
